import { Component, OnInit, Inject, Injectable } from "@angular/core";
import { AlertService } from "../alert/alert.service";
import { HttpClient } from "@angular/common/http";
import { Auction } from "../auction/auction";
import { Router } from "@angular/router";
import { environment } from "../../environments/environment";
import { SESSION_STORAGE, WebStorageService } from "angular-webstorage-service";
import { AppInsightsService } from "src/app/app-insights.service";

@Component({
  selector: "winningbids",
  templateUrl: "./winningbids.component.html",
})
@Injectable({
  providedIn: "root",
})
export class WinningBidsComponent {
  auctions: any;

  userId: string;

  constructor(
    @Inject(SESSION_STORAGE) private storage: WebStorageService,
    private httpClient: HttpClient,
    private alertService: AlertService,
    private router: Router,
    private appInsights: AppInsightsService
  ) {
    this.userId = this.storage.get("userId");
  }

  ngOnInit() {
    this.getMyWinningBids();
  }

  public getMyWinningBids() {
    this.httpClient
      .get(environment.auctionAPI + "/auctionsByUserId/" + this.userId)
      .subscribe(
        (res) => {
          this.auctions = res;
          console.log("Winning Bids are loaded");
        },
        (err) => {
          console.log(err);
          this.alertService.add({ type: "danger", message: err });
          this.appInsights.instance.trackException(err);
        }
      );
    this.appInsights.instance.trackEvent({ name: "LoadedWinningBids" });
  }

  public makePayment(auction) {
    this.router.navigate(["/makePayment"], {
      queryParams: { auction: auction.idauction },
    });
  }
}
