import { Injectable } from "@angular/core";

import * as Msal from "msal";

declare var bootbox: "";
@Injectable()
export class MsalService {
  B2CTodoAccessTokenKey = "b2c.access.token";

  tenantConfig = {
    tenant: "oasmicroservics.onmicrosoft.com",
    // Replace this with your client id
    clientID: "enter Client ID of the Applicatio registered in Azure AD B2C",
    signInPolicy: "B2C_1_signupsingin1",
    signUpPolicy: "B2C_1_signupsingin1",
    redirectUri: "https://onlineauctionapp.azurewebsites.net",
    redirectLocalUri: "http://localhost:4200",
    b2cScopes: [
      "https://oasmicroservics.onmicrosoft.com/oas/user_impersonation",
      "https://oasmicroservics.onmicrosoft.com/oas/read openid offline_access",
    ],
  };

  // Configure the authority for Azure AD B2C
  // Change the authority value as per your configuration
  authority =
    "https://oasmicroservics.b2clogin.com/tfp/" +
    this.tenantConfig.tenant +
    "/" +
    this.tenantConfig.signInPolicy;
  clientApplication = new Msal.UserAgentApplication(
    this.tenantConfig.clientID,
    this.authority,
    this.callbackHandler,
    {
      validateAuthority: false,
      redirectUri: this.tenantConfig.redirectLocalUri,
      cacheLocation: "sessionStorage",
    }
  );

  public callbackHandler(
    errorDesc: any,
    token: any,
    error: any,
    tokenType: any
  ) {
    sessionStorage.clear();
    sessionStorage.setItem("Token", token);
  }

  public login(): void {
    this.clientApplication.authority =
      "https://oasmicroservics.b2clogin.com/tfp/" +
      this.tenantConfig.tenant +
      "/" +
      this.tenantConfig.signInPolicy;
    this.authenticate();
  }

  public signup(): void {
    this.clientApplication.authority =
      "https://oasmicroservics.b2clogin.com/tfp/" +
      this.tenantConfig.tenant +
      "/" +
      this.tenantConfig.signUpPolicy;
    this.authenticate();
  }

  public authenticate(): void {
    this.clientApplication.loginRedirect(this.tenantConfig.b2cScopes);
  }

  logout(): void {
    this.clientApplication.logout();
  }

  isLoggedIn(): boolean {
    return this.clientApplication.getUser() != null;
  }

  getToken() {
    return sessionStorage.getItem("Token");
  }

  getUser() {
    return this.clientApplication.getUser();
  }

  getUserName(): string {
    return this.getUser().name;
  }

  getUserEmail(): string {
    return this.getUser().idToken["emails"][0];
  }

  getUserId() {
    return this.getUser().userIdentifier;
  }
}
